@@ -6,8 +6,9 @@
 """
 __docformat__ = "restructuredtext en"
 
-from cubicweb.interfaces import IGeocodable
 from cubicweb.entities import AnyEntity, fetch_config
+from cubicweb.selectors import is_instance
+from cubicweb.web.views.igeocodable import IGeocodableAdapter
 
 class PhoneNumber(AnyEntity):
     __regid__ = 'PhoneNumber'
@@ -27,8 +28,6 @@ class PostalAddress(AnyEntity):
     __regid__ = 'PostalAddress'
     fetch_attrs, fetch_order = fetch_config(['street', 'street2', 'postalcode',
                                              'city', 'country'])
-    __implements__ = AnyEntity.__implements__ + (IGeocodable,)
-
     def dc_long_title(self):
         lines = []
         if self.street:
@@ -42,3 +41,6 @@ class PostalAddress(AnyEntity):
         if self.country:
             lines.append(self.country)
         return u' '.join(lines)
+
+class PostalAddressIGeocodableAdapter(IGeocodableAdapter):
+    __select__ = is_instance('PostalAddress')
